==> aws-android-sdk-iot-2.7.4-sources.jar: com/amazonaws/services/iot/model/transform/CreateThingTypeRequestMarshaller.java <==
/*
 * Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.AwsJsonWriter;
import com.amazonaws.util.json.JsonUtils;

/**
 * JSON request marshaller for CreateThingTypeRequest
 */
public class CreateThingTypeRequestMarshaller implements
        Marshaller<Request<CreateThingTypeRequest>, CreateThingTypeRequest> {

    public Request<CreateThingTypeRequest> marshall(CreateThingTypeRequest createThingTypeRequest) {
        if (createThingTypeRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(CreateThingTypeRequest)");
        }

        Request<CreateThingTypeRequest> request = new DefaultRequest<CreateThingTypeRequest>(
                createThingTypeRequest, "AWSIot");
        request.setHttpMethod(HttpMethodName.POST);

        String uriResourcePath = "/thing-types/{thingTypeName}";
        uriResourcePath = uriResourcePath.replace(
                "{thingTypeName}",
                (createThingTypeRequest.getThingTypeName() == null) ? "" : StringUtils
                        .fromString(createThingTypeRequest.getThingTypeName()));
        request.setResourcePath(uriResourcePath);
        try {
            StringWriter stringWriter = new StringWriter();
            AwsJsonWriter jsonWriter = JsonUtils.getJsonWriter(stringWriter);
            jsonWriter.beginObject();

            if (createThingTypeRequest.getThingTypeProperties() != null) {
                ThingTypeProperties thingTypeProperties = createThingTypeRequest
                        .getThingTypeProperties();
                jsonWriter.name("thingTypeProperties");
                ThingTypePropertiesJsonMarshaller.getInstance().marshall(thingTypeProperties,
                        jsonWriter);
            }

            jsonWriter.endObject();
            jsonWriter.close();
            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length", Integer.toString(content.length));
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", "application/x-amz-json-1.0");
        }

        return request;
    }
}

==> aws-android-sdk-iot-2.15.0-sources.jar: com/amazonaws/services/iot/model/transform/CreateThingTypeRequestMarshaller.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.AwsJsonWriter;
import com.amazonaws.util.json.JsonUtils;

/**
 * JSON request marshaller for CreateThingTypeRequest
 */
public class CreateThingTypeRequestMarshaller implements
        Marshaller<Request<CreateThingTypeRequest>, CreateThingTypeRequest> {

    public Request<CreateThingTypeRequest> marshall(CreateThingTypeRequest createThingTypeRequest) {
        if (createThingTypeRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(CreateThingTypeRequest)");
        }

        Request<CreateThingTypeRequest> request = new DefaultRequest<CreateThingTypeRequest>(
                createThingTypeRequest, "AWSIot");
        request.setHttpMethod(HttpMethodName.POST);

        String uriResourcePath = "/thing-types/{thingTypeName}";
        uriResourcePath = uriResourcePath.replace(
                "{thingTypeName}",
                (createThingTypeRequest.getThingTypeName() == null) ? "" : StringUtils
                        .fromString(createThingTypeRequest.getThingTypeName()));
        request.setResourcePath(uriResourcePath);
        try {
            StringWriter stringWriter = new StringWriter();
            AwsJsonWriter jsonWriter = JsonUtils.getJsonWriter(stringWriter);
            jsonWriter.beginObject();

            if (createThingTypeRequest.getThingTypeProperties() != null) {
                ThingTypeProperties thingTypeProperties = createThingTypeRequest
                        .getThingTypeProperties();
                jsonWriter.name("thingTypeProperties");
                ThingTypePropertiesJsonMarshaller.getInstance().marshall(thingTypeProperties,
                        jsonWriter);
            }
            if (createThingTypeRequest.getTags() != null) {
                java.util.List<Tag> tags = createThingTypeRequest.getTags();
                jsonWriter.name("tags");
                jsonWriter.beginArray();
                for (Tag tagsItem : tags) {
                    if (tagsItem != null) {
                        TagJsonMarshaller.getInstance().marshall(tagsItem, jsonWriter);
                    }
                }
                jsonWriter.endArray();
            }

            jsonWriter.endObject();
            jsonWriter.close();
            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length", Integer.toString(content.length));
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", "application/x-amz-json-1.0");
        }

        return request;
    }
}
